[0.11] gstreamer: libs: Fix some merge mistakes

Sebastian Dröge slomo at kemper.freedesktop.org
Thu Mar 1 05:51:44 PST 2012


Module: gstreamer
Branch: 0.11
Commit: a8dcb63616687b3f9b91f16e2f73130fc9f13378
URL:    http://cgit.freedesktop.org/gstreamer/gstreamer/commit/?id=a8dcb63616687b3f9b91f16e2f73130fc9f13378

Author: Sebastian Dröge <sebastian.droege at collabora.co.uk>
Date:   Thu Mar  1 14:51:26 2012 +0100

libs: Fix some merge mistakes

---

 libs/gst/base/gstcollectpads2.c        |    4 ++--
 libs/gst/check/gstconsistencychecker.c |   14 +++++---------
 2 files changed, 7 insertions(+), 11 deletions(-)

diff --git a/libs/gst/base/gstcollectpads2.c b/libs/gst/base/gstcollectpads2.c
index 461ac61..f70d366 100644
--- a/libs/gst/base/gstcollectpads2.c
+++ b/libs/gst/base/gstcollectpads2.c
@@ -1662,8 +1662,8 @@ gst_collect_pads2_event (GstPad * pad, GstObject * parent, GstEvent * event)
 
   pads = data->collect;
 
-  GST_DEBUG_OBJECT (data->pad, "Got %s event on sink pad from %s",
-      GST_EVENT_TYPE_NAME (event), GST_OBJECT_NAME (GST_EVENT_SRC (event)));
+  GST_DEBUG_OBJECT (data->pad, "Got %s event on sink pad",
+      GST_EVENT_TYPE_NAME (event));
 
   GST_OBJECT_LOCK (pads);
   event_func = pads->priv->event_func;
diff --git a/libs/gst/check/gstconsistencychecker.c b/libs/gst/check/gstconsistencychecker.c
index a0a176e..f463ed1 100644
--- a/libs/gst/check/gstconsistencychecker.c
+++ b/libs/gst/check/gstconsistencychecker.c
@@ -37,7 +37,7 @@ struct _GstStreamConsistency
 {
   /* FIXME: do we want to track some states per pad? */
   volatile gboolean flushing;
-  volatile gboolean newsegment;
+  volatile gboolean segment;
   volatile gboolean eos;
   volatile gboolean expect_flush;
   GstObject *parent;
@@ -57,7 +57,7 @@ source_pad_data_cb (GstPad * pad, GstPadProbeInfo * info,
   GstMiniObject *data = GST_PAD_PROBE_INFO_DATA (info);
 
   GST_DEBUG_OBJECT (pad, "%p: %d %d %d %d", consist, consist->flushing,
-      consist->newsegment, consist->eos, consist->expect_flush);
+      consist->segment, consist->eos, consist->expect_flush);
 
   if (GST_IS_BUFFER (data)) {
     GST_DEBUG_OBJECT (pad,
@@ -122,15 +122,15 @@ sink_pad_data_cb (GstPad * pad, GstPadProbeInfo * info,
   GstMiniObject *data = GST_PAD_PROBE_INFO_DATA (info);
 
   GST_DEBUG_OBJECT (pad, "%p: %d %d %d %d", consist, consist->flushing,
-      consist->newsegment, consist->eos, consist->expect_flush);
+      consist->segment, consist->eos, consist->expect_flush);
 
   if (GST_IS_BUFFER (data)) {
     GST_DEBUG_OBJECT (pad, "Buffer %" GST_TIME_FORMAT,
         GST_TIME_ARGS (GST_BUFFER_TIMESTAMP (GST_BUFFER (data))));
     /* If an EOS went through, a buffer would be invalid */
     fail_if (consist->eos, "Buffer received after EOS");
-    /* Buffers need to be preceded by a newsegment event */
-    fail_unless (consist->newsegment, "Buffer received without newsegment");
+    /* Buffers need to be preceded by a segment event */
+    fail_unless (consist->segment, "Buffer received without segment");
   } else if (GST_IS_EVENT (data)) {
     GstEvent *event = (GstEvent *) data;
 
@@ -266,10 +266,6 @@ gst_consistency_checker_free (GstStreamConsistency * consist)
   GList *node;
   GstStreamConsistencyProbe *p;
 
-  /* Remove the data probe */
-  gst_pad_remove_probe (consist->pad, consist->probeid);
-  g_object_unref (consist->pad);
-
   /* Remove the data probes */
   for (node = consist->pads; node; node = g_list_next (node)) {
     p = (GstStreamConsistencyProbe *) node->data;



More information about the gstreamer-commits mailing list